@@ -1,3 +1,3 @@
-((nil . ((compile-command . "guix build --file=guix.scm")))
+((nil . ((compile-command . "guix shell emacs-minimal -- ./build-package")))
  (prog-mode (eval flymake-mode))
  (magit-status-mode (magit-todos-exclude-globs)))
